@@ -1,8 +1,8 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 
-__author__ = 'Chris Griffith'
-__version__ = '4.2.0'
+__author__ = "Chris Griffith"
+__version__ = "5.1.0"
 
 from box.box import Box
 from box.box_list import BoxList
